@@ -1,5 +1,5 @@
 from contextlib import contextmanager
-from typing import Optional
+from typing import ContextManager, Optional
 from urllib.parse import quote
 
 import requests
@@ -7,7 +7,7 @@ from docker import DockerClient
 from pika import BlockingConnection, ConnectionParameters, PlainCredentials
 from pika.exceptions import AMQPConnectionError
 
-from yellowbox.containers import create_and_pull, get_ports
+from yellowbox.containers import create_and_pull, get_ports, upload_file
 from yellowbox.retry import RetrySpec
 from yellowbox.subclasses import RunMixin, SingleContainerService
 
@@ -18,21 +18,24 @@ RABBIT_HTTP_API_PORT = 15672
 
 
 class RabbitMQService(SingleContainerService, RunMixin):
-    def __init__(self, docker_client: DockerClient, image='rabbitmq:latest', *, user="guest",
-                 password="guest",
+    def __init__(self, docker_client: DockerClient, image='rabbitmq:latest', *, user="guest", password="guest",
                  virtual_host="/", **kwargs):
         self.user = user
         self.password = password
         self.virtual_host = virtual_host
         super().__init__(create_and_pull(
-            docker_client, image, publish_all_ports=True, detach=True, environment={
-                'RABBITMQ_DEFAULT_USER': user,
-                'RABBITMQ_DEFAULT_PASS': password,
-                'RABBITMQ_DEFAULT_VHOST': virtual_host
-            },
-            ports={RABBIT_HTTP_API_PORT: None},  # Forward management port by default.
+            docker_client, image, publish_all_ports=True, detach=True,
+            ports={RABBIT_HTTP_API_PORT: 0},  # Forward management port by default.
         ), **kwargs)
 
+        upload_file(self.container, '/etc/rabbitmq/rabbitmq.conf',
+                    f'''
+                    default_pass = {password}
+                    default_user = {user}
+                    default_vhost = {virtual_host}
+                    loopback_users = none
+                    '''.encode())
+
     def connection_port(self):
         return get_ports(self.container)[RABBIT_DEFAULT_PORT]
 
@@ -91,7 +94,7 @@ class RabbitMQService(SingleContainerService, RunMixin):
     @classmethod
     @contextmanager
     def run(cls, docker_client: DockerClient, *, enable_management=False, **kwargs):
-        cmg: RabbitMQService = super().run(docker_client, **kwargs)
+        cmg: ContextManager[RabbitMQService] = super().run(docker_client, **kwargs)
         with cmg as ret:
             if enable_management:
                 ret.enable_management()
